@@ -19,32 +19,14 @@ from os_brick import exception
 from os_brick.initiator.connectors import rbd
 from os_brick.initiator import linuxrbd
 from os_brick.privileged import rootwrap as priv_rootwrap
+from os_brick.tests.initiator.connectors import test_base_rbd
 from os_brick.tests.initiator import test_connector
 from os_brick import utils
 
 
 @ddt.ddt
-class RBDConnectorTestCase(test_connector.ConnectorTestCase):
-
-    def setUp(self):
-        super(RBDConnectorTestCase, self).setUp()
-
-        self.user = 'fake_user'
-        self.pool = 'fake_pool'
-        self.volume = 'fake_volume'
-        self.clustername = 'fake_ceph'
-        self.hosts = ['192.168.10.2']
-        self.ports = ['6789']
-        self.keyring = "[client.cinder]\n  key = test\n"
-
-        self.connection_properties = {
-            'auth_username': self.user,
-            'name': '%s/%s' % (self.pool, self.volume),
-            'cluster_name': self.clustername,
-            'hosts': self.hosts,
-            'ports': self.ports,
-            'keyring': self.keyring,
-        }
+class RBDConnectorTestCase(test_base_rbd.RBDConnectorTestMixin,
+                           test_connector.ConnectorTestCase):
 
     def test_get_search_path(self):
         rbd_connector = rbd.RBDConnector(None)
@@ -140,24 +122,6 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
                               conn._check_or_get_keyring_contents, keyring,
                               'cluster', 'user')
 
-    @ddt.data((['192.168.1.1', '192.168.1.2'],
-               ['192.168.1.1', '192.168.1.2']),
-              (['3ffe:1900:4545:3:200:f8ff:fe21:67cf',
-                'fe80:0:0:0:200:f8ff:fe21:67cf'],
-               ['[3ffe:1900:4545:3:200:f8ff:fe21:67cf]',
-                '[fe80:0:0:0:200:f8ff:fe21:67cf]']),
-              (['foobar', 'fizzbuzz'], ['foobar', 'fizzbuzz']),
-              (['192.168.1.1',
-                '3ffe:1900:4545:3:200:f8ff:fe21:67cf',
-                'hello, world!'],
-               ['192.168.1.1',
-                '[3ffe:1900:4545:3:200:f8ff:fe21:67cf]',
-                'hello, world!']))
-    @ddt.unpack
-    def test_sanitize_mon_host(self, hosts_in, hosts_out):
-        conn = rbd.RBDConnector(None)
-        self.assertEqual(hosts_out, conn._sanitize_mon_hosts(hosts_in))
-
     @mock.patch('os_brick.initiator.connectors.rbd.tempfile.mkstemp')
     def test_create_ceph_conf(self, mock_mkstemp):
         mockopen = mock.mock_open()
@@ -232,7 +196,7 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
                '--mon_host', '192.168.10.2:6789']
         execute_call2 = mock.call(*cmd, root_helper=None, run_as_root=True)
         mock_execute.assert_has_calls([execute_call1])
-        self.assertFalse(execute_call2 in mock_execute.mock_calls)
+        self.assertNotIn(execute_call2, mock_execute.mock_calls)
         expected_info = {'path': '/dev/rbd/pool/image',
                          'type': 'block'}
         self.assertEqual(expected_info, device_info)
@@ -251,16 +215,6 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
                          'type': 'block'}
         self.assertEqual(expected_info, device_info)
 
-    @mock.patch.object(priv_rootwrap, 'execute', return_value=None)
-    def test_connect_local_volume_without_auth(self, mock_execute):
-        rbd_connector = rbd.RBDConnector(None, do_local_attach=True)
-        conn = {'name': 'pool/image',
-                'hosts': ['192.168.10.2'],
-                'ports': ['6789']}
-        self.assertRaises(exception.BrickException,
-                          rbd_connector.connect_volume,
-                          conn)
-
     @mock.patch('os_brick.initiator.connectors.rbd.'
                 'RBDConnector._local_attach_volume')
     def test_connect_volume_local(self, mock_local_attach):
@@ -489,20 +443,6 @@ class RBDConnectorTestCase(test_connector.ConnectorTestCase):
         mock_delete.assert_called_once_with(mock_config.return_value)
         mock_open.assert_not_called()
 
-    def test__get_rbd_args(self):
-        res = rbd.RBDConnector._get_rbd_args(self.connection_properties, None)
-        expected = ['--id', self.user,
-                    '--mon_host', self.hosts[0] + ':' + self.ports[0]]
-        self.assertEqual(expected, res)
-
-    def test__get_rbd_args_with_conf(self):
-        res = rbd.RBDConnector._get_rbd_args(self.connection_properties,
-                                             mock.sentinel.conf_path)
-        expected = ['--id', self.user,
-                    '--mon_host', self.hosts[0] + ':' + self.ports[0],
-                    '--conf', mock.sentinel.conf_path]
-        self.assertEqual(expected, res)
-
     @mock.patch.object(rbd.RBDConnector, '_get_rbd_args')
     @mock.patch.object(rbd.RBDConnector, '_execute')
     def test_find_root_device(self, mock_execute, mock_args):
